#!/usr/bin/env python3

import argparse

from glinkfix import fixlink

# --------------------------------------------------------------------


def main():

    # Build a python argument parser

    msg = """This program takes a Google Drive sharing link for a
    file and repackages it into a link that can be downloaded directly
    (e.g. using curl) or embedded in a document to be viewed (e.g. an
    image in a markdown document). Note: there is a size limit of 40MB
    for a single file when using Google Drive links in this manner."""

    epi = "Version: 1.0.6"
    parser = argparse.ArgumentParser(description=msg, epilog=epi)
    group = parser.add_mutually_exclusive_group(required=True)

    msg = """repackage the link for viewing (e.g. as an embedded
    link in a markdown document)."""
    group.add_argument('-v', '--view',
                       action='store_true',
                       help=msg)

    msg = """repackage the link for downloading (e.g. downloading
    using curl)."""
    group.add_argument('-d', '--download',
                       action='store_true',
                       help=msg)

    args = parser.parse_args()

    # ----------------------------------------------------------

    fixlink(args)

    return


# --------------------------------------------------------------------

if __name__ == '__main__':
    main()



import os


def clear():
    """Clear the screen

    This is an os-agnostic version, which will work with both Windows
    and Linux.
    """
    return os.system('clear' if os.name == 'posix' else 'cls')

# --------------------------------------------------------------------


def fixlink(args):

    clear()

    template = "https://drive.google.com/uc?export=ACTION&id=IDNUM"
    print('Enter a Google Drive URL to be repackaged:\n')
    oldlink = input()
    resourcekey = None

    try:
        parts = oldlink.split('/')
        id = parts[-2]
        if 'resourcekey' in oldlink:
            resourcekey = oldlink.split('&')[-1]
    except Exception as e:
        print(f'\nCannot repackage link: {e}')
        return

    if parts[3] != 'file':
        print('Link to repackage must point to a file.')
        return

    if args.view:
        action = template.replace('ACTION', 'view')
        linkType = 'viewing'
    elif args.download:
        action = template.replace('ACTION', 'download')
        linkType = 'downloading'
    else:
        pass

    print(f'\nClean {linkType} URL is:\n')
    newlink = action.replace("IDNUM", id)
    if resourcekey:
        newlink += f'&{resourcekey}'
    print(f'{newlink}\n')

    return

# --------------------------------------------------------------------


if __name__ == '__main__':
    pass
